@@ -28,13 +28,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-commands.h 5326 2006-12-02 15:03:22Z pborelli $
+ * $Id$
  */
 
 #ifndef __GEDIT_COMMANDS_H__
 #define __GEDIT_COMMANDS_H__
 
-#include <gtk/gtkaction.h>
+#include <gtk/gtk.h>
 #include <gedit/gedit-window.h>
 
 G_BEGIN_DECLS
@@ -51,17 +51,18 @@ gint		 gedit_commands_load_uris		(GeditWindow         *window,
 							 const GeditEncoding *encoding,
 							 gint                 line_pos);
 
+void		 gedit_commands_save_document		(GeditWindow         *window,
+                                                         GeditDocument       *document);
+
+void		 gedit_commands_save_all_documents 	(GeditWindow         *window);
+
 /*
  * Non-exported functions
  */
- 
-gint		_gedit_cmd_load_files			(GeditWindow         *window,
-							 const GSList        *uris,
-							 const GeditEncoding *encoding);
-							 
+
 /* Create titled documens for non-existing URIs */
 gint		_gedit_cmd_load_files_from_prompt	(GeditWindow         *window,
-							 const GSList        *uris,
+							 GSList              *files,
 							 const GeditEncoding *encoding,
 							 gint                 line_pos);
 
@@ -79,8 +80,6 @@ void		_gedit_cmd_file_revert			(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_file_open_uri		(GtkAction   *action,
 							 GeditWindow *window);
-void		_gedit_cmd_file_page_setup		(GtkAction   *action,
-							 GeditWindow *window);
 void		_gedit_cmd_file_print_preview		(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_file_print			(GtkAction   *action,
@@ -117,6 +116,10 @@ void		_gedit_cmd_view_show_side_pane		(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_view_show_bottom_pane	(GtkAction   *action,
 							 GeditWindow *window);
+void		_gedit_cmd_view_toggle_fullscreen_mode	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_view_leave_fullscreen_mode	(GtkAction   *action,
+							 GeditWindow *window);
 
 void		_gedit_cmd_search_find			(GtkAction   *action,
 							 GeditWindow *window);
@@ -151,6 +154,13 @@ void		_gedit_cmd_file_close_tab 		(GeditTab    *tab,
 void		_gedit_cmd_file_save_documents_list	(GeditWindow *window,
 							 GList       *docs);
 
+
+#if !GTK_CHECK_VERSION (2, 17, 4)
+void		_gedit_cmd_file_page_setup		(GtkAction   *action,
+							 GeditWindow *window);
+#endif
+
+
 G_END_DECLS
 
 #endif /* __GEDIT_COMMANDS_H__ */ 
