@@ -115,6 +115,12 @@ gedit_gio_document_saver_dispose (GObject *object)
 		priv->stream = NULL;
 	}
 
+	if (priv->input != NULL)
+	{
+		g_object_unref (priv->input);
+		priv->input = NULL;
+	}
+
 	G_OBJECT_CLASS (gedit_gio_document_saver_parent_class)->dispose (object);
 }
 
@@ -146,7 +152,7 @@ gedit_gio_document_saver_class_init (GeditGioDocumentSaverClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GeditDocumentSaverClass *saver_class = GEDIT_DOCUMENT_SAVER_CLASS (klass);
 
-	object_class->finalize = gedit_gio_document_saver_dispose;
+	object_class->dispose = gedit_gio_document_saver_dispose;
 
 	saver_class->save = gedit_gio_document_saver_save;
 	saver_class->get_file_size = gedit_gio_document_saver_get_file_size;
@@ -168,12 +174,12 @@ static void
 remote_save_completed_or_failed (GeditGioDocumentSaver *gvsaver, 
 				 AsyncData 	       *async)
 {
-	if (async)
-		async_data_free (async);
-
 	gedit_document_saver_saving (GEDIT_DOCUMENT_SAVER (gvsaver),
 				     TRUE,
 				     gvsaver->priv->error);
+
+	if (async)
+		async_data_free (async);
 }
 
 static void
@@ -194,7 +200,7 @@ remote_get_info_cb (GFile        *source,
 	GFileInfo *info;
 	GError *error = NULL;
 
-	saver = async->saver;
+	gedit_debug (DEBUG_SAVER);
 
 	/* check cancelled state manually */
 	if (g_cancellable_is_cancelled (async->cancellable))
@@ -203,6 +209,8 @@ remote_get_info_cb (GFile        *source,
 		return;
 	}
 	
+	saver = async->saver;
+
 	gedit_debug_message (DEBUG_SAVER, "Finished query info on file");
 	info = g_file_query_info_finish (source, res, &error);
 
@@ -228,7 +236,9 @@ close_async_ready_get_info_cb (GOutputStream *stream,
 			       AsyncData     *async)
 {
 	GError *error = NULL;
-	
+
+	gedit_debug (DEBUG_SAVER);
+
 	/* check cancelled state manually */
 	if (g_cancellable_is_cancelled (async->cancellable))
 	{
@@ -299,6 +309,8 @@ async_write_cb (GOutputStream *stream,
 	gssize bytes_written;
 	GError *error = NULL;
 
+	gedit_debug (DEBUG_SAVER);
+
 	/* Check cancelled state manually */
 	if (g_cancellable_is_cancelled (async->cancellable))
 	{
@@ -342,6 +354,8 @@ write_file_chunk (AsyncData *async)
 {
 	GeditGioDocumentSaver *gvsaver;
 
+	gedit_debug (DEBUG_SAVER);
+
 	gvsaver = async->saver;
 
 	g_output_stream_write_async (G_OUTPUT_STREAM (gvsaver->priv->stream),
@@ -360,6 +374,8 @@ read_file_chunk (AsyncData *async)
 	GeditDocumentInputStream *dstream;
 	GError *error = NULL;
 
+	gedit_debug (DEBUG_SAVER);
+
 	gvsaver = async->saver;
 	async->written = 0;
 
@@ -402,6 +418,8 @@ async_replace_ready_callback (GFile        *source,
 	GFileOutputStream *file_stream;
 	GError *error = NULL;
 
+	gedit_debug (DEBUG_SAVER);
+
 	/* Check cancelled state manually */
 	if (g_cancellable_is_cancelled (async->cancellable))
 	{
@@ -488,7 +506,9 @@ mount_ready_callback (GFile        *file,
 {
 	GError *error = NULL;
 	gboolean mounted;
-	
+
+	gedit_debug (DEBUG_SAVER);
+
 	/* manual check for cancelled state */
 	if (g_cancellable_is_cancelled (async->cancellable))
 	{
@@ -539,7 +559,9 @@ check_modification_callback (GFile        *source,
 	GeditGioDocumentSaver *gvsaver;
 	GError *error = NULL;
 	GFileInfo *info;
-	
+
+	gedit_debug (DEBUG_SAVER);
+
 	/* manually check cancelled state */
 	if (g_cancellable_is_cancelled (async->cancellable))
 	{
