@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-changecase-plugin.c 6498 2008-09-07 13:50:57Z pborelli $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -275,7 +275,7 @@ free_window_data (WindowData *data)
 {
 	g_return_if_fail (data != NULL);
 
-	g_free (data);
+	g_slice_free (WindowData, data);
 }
 
 static void
@@ -284,16 +284,24 @@ update_ui_real (GeditWindow  *window,
 {
 	GtkTextView *view;
 	GtkAction *action;
+	gboolean sensitive = FALSE;
 
 	gedit_debug (DEBUG_PLUGINS);
 
 	view = GTK_TEXT_VIEW (gedit_window_get_active_view (window));
 
+	if (view != NULL)
+	{
+		GtkTextBuffer *buffer;
+
+		buffer = gtk_text_view_get_buffer (view);
+		sensitive = (gtk_text_view_get_editable (view) &&
+			     gtk_text_buffer_get_has_selection (buffer));
+	}
+
 	action = gtk_action_group_get_action (data->action_group,
 					      "ChangeCase");
-	gtk_action_set_sensitive (action,
-				  (view != NULL) &&
-				  gtk_text_view_get_editable (view));
+	gtk_action_set_sensitive (action, sensitive);
 }
 
 static void
@@ -306,7 +314,7 @@ impl_activate (GeditPlugin *plugin,
 
 	gedit_debug (DEBUG_PLUGINS);
 
-	data = g_new (WindowData, 1);
+	data = g_slice_new (WindowData);
 
 	manager = gedit_window_get_ui_manager (window);
 
@@ -327,6 +335,7 @@ impl_activate (GeditPlugin *plugin,
 	if (data->ui_id == 0)
 	{
 		g_warning ("%s", error->message);
+		free_window_data (data);
 		return;
 	}
 
